#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

import os
import sys
from iobase.xmldata import XmlConfNode
from fal_info import (FAL_SHARES_PATH,
    FAL_SERVICECTRL_PATH, FAL_APPLENETWORK_PATH)

# debpkg_utils.pyインポート用
sys.path.append(os.path.join(
    os.path.dirname(os.path.abspath(__file__)),
    os.path.pardir))

from debpkg_utils import *

import manualctrl


PACKAGE = "appleshare"
SERVICE = "netatalk"
USB_CONF_PATH = "/mnt/data/conf/netatalk/usb"
REMOVE_LIST = [
    "/mnt/data/etc/netatalk",
    "/mnt/data/conf/netatalk",
    "/mnt/data/etc/avahi/services/timemachine.service",
    "/mnt/sataraid1/AppleDB"]

UPDATE_REAL_CONF_CMD_PATH = "/mnt/data/libexec/evh/evh_apple_mod.py"
TG_LIST_XPATH = "sharelist/share"
PACK_XPATH = "event/eventinfo/shares"
TG_NODE_XPATH = "shareservice/appleshare[@enable='true']"

DEFAULT_FAL_CONF_PATH = "/mnt/data/xmlconf/defaults/config-applenetwork.xml"


class ShareXmlConfModifier(BaseXmlConfModifier):

    FAL = FAL_SHARES_PATH

    class ShareServiceModifyInfo():
        PAR_XPATH = "//shareservice"
        INSTALL_NODE_LIST = [XmlConfNode(
                """<appleshare enable="false" timemachine="false"/>""")]
        REMOVE_XPATH_LIST = ["appleshare"]

    MODIFY_INFO_LIST = [ShareServiceModifyInfo]


class ServiceXmlConfModifier(BaseXmlConfModifier):

    FAL = FAL_SERVICECTRL_PATH

    class ShareListModifyInfo():
        PAR_XPATH = "//servicectrl/servicelist"
        INSTALL_NODE_LIST = [
            XmlConfNode("<service enable='true'><name>%s</name></service>" % SERVICE)]
        REMOVE_XPATH_LIST = ["service[name='%s']" % SERVICE]

    class CategoryShareListModifyInfo():
        PAR_XPATH = "//category[name='disk' or name='share' or name='network']/servicelist"
        INSTALL_NODE_LIST = [
            XmlConfNode("<service><name>%s</name></service>" % SERVICE)]
        REMOVE_XPATH_LIST = ["service[name='%s']" % SERVICE]
       
    MODIFY_INFO_LIST = [ShareListModifyInfo, CategoryShareListModifyInfo]


if __name__ == "__main__":
    share_ins = ShareXmlConfModifier()
    service_ins = ServiceXmlConfModifier()

    if sys.argv[1] == "postinst_configure_install":
        share_ins.install()
        service_ins.install()
        msg_xml_modify_with_file(PACKAGE)
        set_default_conf(FAL_APPLENETWORK_PATH, DEFAULT_FAL_CONF_PATH)
        update_real_conf(UPDATE_REAL_CONF_CMD_PATH, FAL_SHARES_PATH,
                         TG_LIST_XPATH, PACK_XPATH, TG_NODE_XPATH)
        update_conf(FAL_APPLENETWORK_PATH)
        ctrl_usb_conf(USB_CONF_PATH)
        manualctrl.install()
        service_start(SERVICE, is_check_mounted=True)

    elif sys.argv[1] == "postinst_configure_upgrade":
        # ここで既存の設定に対しての処理をする
        service_stop(SERVICE)
        manualctrl.update()
        update_real_conf(UPDATE_REAL_CONF_CMD_PATH, FAL_SHARES_PATH,
                         TG_LIST_XPATH, PACK_XPATH, TG_NODE_XPATH)
        service_start(SERVICE, is_check_mounted=True)

    elif sys.argv[1] == "prerm_remove":
        share_ins.remove()
        service_ins.remove()
        service_stop(SERVICE)
        remove_files(REMOVE_LIST)
        service_restart("avahi-daemon")
        manualctrl.uninstall()

    elif sys.argv[1] == "prerm_upgrade":
        # upgrade時は既存の設定を削除しない
        service_stop(SERVICE)
